#
# spec file for package python-librouteros
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-librouteros
Version:        3.2.1
Release:        3.5
Summary:        Python implementation of MikroTik RouterOS API
License:        GPL-2.0-or-later
URL:            https://github.com/luqasz/librouteros
Source:         https://github.com/luqasz/librouteros/archive/%{version}.tar.gz#/librouteros-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#luqasz/librouteros#a9349dfdc1d8e7a915567766e0d18b07544323dc
Patch0:         migrate-to-setup-method.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Python implementation of MikroTik RouterOS API.
http://wiki.mikrotik.com/wiki/API

%prep
%autosetup -p1 -n librouteros-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Broken test upstream
%pytest -k 'not test_rawCmd_calls_writeSentence' tests/unit

%files %{python_files}
%license LICENSE
%doc CHANGELOG.rst README.rst
%{python_sitelib}/librouteros
%{python_sitelib}/librouteros-%{version}.dist-info

%changelog
* Tue Aug 20 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch migrate-to-setup-method.patch:
  * Migrate to using setup_method().
* Tue Jan 23 2024 Steve Kowalik <steven.kowalik@suse.com>
- Skip a broken test.
- Switch to autosetup and pyproject macros.
- Stop using greedy globs in %%files.
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 3.2.1
  * Fix non ASCII API word encoding
* Wed Mar 23 2022 pgajdos@suse.com
- python-mock is not required for build
* Mon Feb  7 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove BuildRequires on chainmap, it's a builtin now.
* Thu Nov 18 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 3.2.0
  * Ignore character decoding errors
* Fri Dec 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.1.0
  * Add In operator
* Mon Jul 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.2
  * Fix generator yielding
* Mon Apr 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.1
  * Add typing annotations
* Thu Nov  7 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.0
  * Introduce query support.
  * Path object for easy query and common operations.
  * yield each item instead of returning tuple of items. Greatly
    reduces memory usage.
  * Drop pre python 3.6 support.
  * Replace pylava with pylint.
  * Add yapf formatter.
  * Replace py.path with builtin pathlib.
  * connect() accepts only one login_method parameter.
  * Drop socker exceptions wrapping.
  * Remove ConnectionError exception.
  * Renamed LibError to LibRouterosError.
  * Changed exceptions inheritance.
  * Removed joinPath()
- Do not longer build against python2 (upstream dropped support)
* Sat Oct 12 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.0
- Specfile cleanup
- Fix license
- Use tarball from github github
* Mon Aug  7 2017 mardnh@gmx.de
- Initial package, version 1.0.2
